Index: src/ppc/builtins-ppc.cc |
diff --git a/src/ppc/builtins-ppc.cc b/src/ppc/builtins-ppc.cc |
index dba44d2540b9ac3fb8bd7c53881dd1c2c1ed5430..8a14586c886b2dc8f60ef44297474a6a237a2442 100644 |
--- a/src/ppc/builtins-ppc.cc |
+++ b/src/ppc/builtins-ppc.cc |
@@ -601,8 +601,8 @@ static void Generate_JSConstructStubHelper(MacroAssembler* masm, |
__ JumpIfSmi(r3, &use_receiver); |
// If the type of the result (stored in its map) is less than |
- // FIRST_SPEC_OBJECT_TYPE, it is not an object in the ECMA sense. |
- __ CompareObjectType(r3, r4, r6, FIRST_SPEC_OBJECT_TYPE); |
+ // FIRST_JS_RECEIVER_TYPE, it is not an object in the ECMA sense. |
+ __ CompareObjectType(r3, r4, r6, FIRST_JS_RECEIVER_TYPE); |
__ bge(&exit); |
// Throw away the result of the constructor invocation and use the |